==> aiobungie-0.2.4-py3-none-any.whl: aiobungie/types/character.py <==
'''
MIT License

Copyright (c) 2020 - Present nxtlo

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
'''
from typing import TypedDict, Union
from ..utils import Image
from ..utils.enums import DestinyCharecter, DestinyRace, DestinyGender
from datetime import datetime


class Character(TypedDict):
	emblem_icon: Union[Image, str]
	emblem: Union[Image, str]
	light: int
	total_played_time: int
	last_player: datetime
	id: int
	_class: DestinyCharecter
	member_id: int
	last_session: int
	race: DestinyRace
	gender: DestinyGender

==> aiobungie-0.2.5a2-py3-none-any.whl: aiobungie/types/character.py <==
'''
MIT License

Copyright (c) 2020 - Present nxtlo

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
'''

from __future__ import annotations
from typing import TypedDict, Dict
from ..utils import Image
from ..utils.enums import DestinyClass, DestinyRace, DestinyGender, Stat, MembershipType
from datetime import datetime


class CharacterData(TypedDict):
	membershipId: int
	membershipType: MembershipType
	characterId: int
	dateLastPlayed: datetime
	minutesPlayedTotal: int
	light: int
	stats: Stat
	raceType: DestinyRace
	classType: DestinyClass
	genderType: DestinyGender
	emblemPath: Image
	emblemBackgroundPath: Image
	emblemHash: int
	baseCharacterLevel: int
	titleRecordHash: int

class CharacterImpl(CharacterData, total=False):
	pass
